/**
 * @typedef {import('interface-datastore').Datastore} Datastore
 * @typedef {import('interface-datastore').Pair} Pair
 * @typedef {import('interface-datastore').Batch} Batch
 * @typedef {import('interface-datastore').Query} Query
 * @typedef {import('interface-datastore').KeyQuery} KeyQuery
 * @typedef {import('interface-datastore').Options} QueryOptions
 * @typedef {import('abstract-level').AbstractLevel<any, string, Uint8Array>} LevelDb
 */
/**
 * A datastore backed by leveldb
 */
export class LevelDatastore extends BaseDatastore {
    /**
     * @param {string | LevelDb} path
     * @param {import('level').DatabaseOptions<string, Uint8Array>} [opts]
     */
    constructor(path: string | import("abstract-level/types/abstract-level").AbstractLevel<any, string, Uint8Array>, opts?: import("level").DatabaseOptions<string, Uint8Array> | undefined);
    /** @type {LevelDb} */
    db: import("abstract-level/types/abstract-level").AbstractLevel<any, string, Uint8Array>;
    /**
     * @param {Key} key
     * @param {Uint8Array} value
     */
    put(key: Key, value: Uint8Array): Promise<void>;
    /**
     * @param {Key} key
     * @returns {Promise<Uint8Array>}
     */
    get(key: Key): Promise<Uint8Array>;
    /**
     * @param {Key} key
     * @returns {Promise<boolean>}
     */
    has(key: Key): Promise<boolean>;
    /**
     * @param {Key} key
     * @returns {Promise<void>}
     */
    delete(key: Key): Promise<void>;
    /**
     * @param {Query} q
     */
    query(q: Query): AsyncIterable<import("interface-datastore").Pair>;
    /**
     * @param {KeyQuery} q
     */
    queryKeys(q: KeyQuery): AsyncIterable<Key>;
    /**
     * @param {object} opts
     * @param {boolean} opts.values
     * @param {string} [opts.prefix]
     * @returns {AsyncIterable<Pair>}
     */
    _query(opts: {
        values: boolean;
        prefix?: string | undefined;
    }): AsyncIterable<Pair>;
}
export type Datastore = import('interface-datastore').Datastore;
export type Pair = import('interface-datastore').Pair;
export type Batch = import('interface-datastore').Batch;
export type Query = import('interface-datastore').Query;
export type KeyQuery = import('interface-datastore').KeyQuery;
export type QueryOptions = import('interface-datastore').Options;
export type LevelDb = import('abstract-level').AbstractLevel<any, string, Uint8Array>;
import { BaseDatastore } from "datastore-core";
import { Key } from "interface-datastore";
//# sourceMappingURL=index.d.ts.map